@@ -1,16 +1,27 @@
 ## File Name: ccov.np.R
-## File Version: 1.15
+## File Version: 1.190
 
 
 #---- nonparametric estimation of conditional covariance
 ccov.np <- function( data, score, bwscale=1.1, thetagrid=seq( -3,3,len=200),
-        progress=TRUE, scale_score=TRUE )
+        progress=TRUE, scale_score=TRUE, adjust_thetagrid=TRUE, smooth=TRUE )
 {
     # number of Items I
     I <- ncol(data)
     # z-standardization of score
-    if ( scale_score ){
-        score <- scale( score )[,1]
+    if (scale_score){
+        score <- scale(score)[,1]
+    } else {
+        bwscale <- bwscale*stats::sd(score, na.rm=TRUE)
+    }
+    # adjust thetagrid
+    if (adjust_thetagrid & smooth){
+        score_rg <- range(score)
+        thetagrid <- seq(score_rg[1], score_rg[2], length=length(thetagrid))
+    }
+    if (!smooth){
+        score <- round(score,3)
+        thetagrid <- sort(unique(score))
     }
     # matrix of item response functions
     if (progress){
@@ -18,7 +29,7 @@ ccov.np <- function( data, score, bwscale=1.1, thetagrid=seq( -3,3,len=200),
         cat("...........................................................\n" )
         cat("Nonparametric ICC estimation \n " )
     }
-    icc.items <- matrix( 0, length(thetagrid), I )
+    icc_items <- matrix( 0, length(thetagrid), I )
     if ( I >=20 ){
         display <- seq( 1, I, floor( I/20 ) )[ 2:20 ]
     } else {
@@ -29,29 +40,23 @@ ccov.np <- function( data, score, bwscale=1.1, thetagrid=seq( -3,3,len=200),
         obs_ii <- ! is.na( data[,ii] )
         x <- score[ obs_ii ]
         y <- data[ obs_ii, ii ]
-        icc.items[,ii] <- stats::ksmooth( x, y, bandwidth=bwscale * length(x)^(-1/5),
-                            x.points=thetagrid, kernel="normal")$y
-        if ( i < 20 ){
-            if ( ii==display[i] & progress ){
-                cat( paste( 5*i, "% ", sep="" ) )
-                i <- i + 1
-                if (i==11){
-                    cat("\n" )
-                }
-                utils::flush.console()
-            }
-        }
+        icc_items[,ii] <- ccov_np_regression(x=x, y=y, xgrid=thetagrid,
+                                bwscale=bwscale, smooth=smooth, score=score)
+        i <- ccov_np_print_progress(progress=progress, i=i, ii=ii, display=display)
     }
+
     sirt_progress_cat(progress=progress)
-    # weights thetagrid
-    wgt.thetagrid <- sirt_dnorm_discrete(x=thetagrid)
-    if (progress ){
+    #-- weights thetagrid
+    wgt_thetagrid <- ccov_np_score_density(score=score, thetagrid=thetagrid, smooth=smooth)
+
+    #-- display progress
+    if (progress){
         cat("...........................................................\n" )
         cat("Nonparametric Estimation of conditional covariances \n " )
         utils::flush.console()
     }
     # calculation of conditional covariance
-    ccov.table <- data.frame( "item1ID"=rep( 1:I, I ), "item2ID"=rep( 1:I, each=I ) )
+    ccov.table <- data.frame( "item1ID"=rep( 1:I, I), "item2ID"=rep( 1:I, each=I ) )
     ccov.table <- ccov.table[ ccov.table$item1ID < ccov.table$item2ID, ]
     ccov.table$N <- apply( ccov.table, 1, FUN=function(ll){
                     sum( rowSums( is.na( data[, c( ll[1], ll[2] ) ] ) )==0 ) } )
@@ -61,44 +66,35 @@ ccov.np <- function( data, score, bwscale=1.1, thetagrid=seq( -3,3,len=200),
     ccov.table$itempair <- paste( ccov.table$item1, ccov.table$item2, sep="-" )
     # smoothing all item pairs
     # calculate conditional covariances
-    FF <- nrow( ccov.table )
-    ccor.matrix <- ccov.matrix <- prod.matrix <- matrix( 0, nrow=length(thetagrid ), ncol=FF )
+    FF <- nrow(ccov.table)
+    ccov.matrix <- prod.matrix <- matrix( 0, nrow=length(thetagrid ), ncol=FF )
     ii <- 1
     for (ff in 1:FF){
         if (FF>20){
-            display <- seq( 1, FF, floor( FF/20  ) )[ 2:20 ]
+            display <- seq( 1, FF, floor( FF/20 ) )[ 2:20 ]
         } else {
             display <- seq(1,FF)
         }
         data.ff <- data[, c( ccov.table[ff,1], ccov.table[ff,2] ) ]
-        which.ff <- which( rowSums( is.na( data.ff ) )==0  )
+        which.ff <- which( rowSums( is.na(data.ff) )==0  )
         data.ff <- data.ff[ which.ff, ]
-        prod.matrix[,ff] <- stats::ksmooth( x=score[ which.ff],
-                                        y=data.ff[,1]*data.ff[,2],
-                                        bandwidth=bwscale * length(which.ff)^(-1/5),
-                                        x.points=thetagrid, kernel="normal")$y
-        ccov.matrix[, ff ] <- prod.matrix[,ff] - icc.items[, ccov.table[ff,1] ] *
-                                        icc.items[, ccov.table[ff,2] ]
-        if ( ii < 20 ){
-            if ( ff==display[ii] & progress ){
-                cat( paste( 5*ii, "% ", sep="" ) )
-                ii <- ii + 1
-                utils::flush.console()
-                if (ii==11){
-                    cat("\n" )
-                }
-            }
-        }
+        prod.matrix[,ff] <- ccov_np_regression(x=score[ which.ff], y=data.ff[,1]*data.ff[,2],
+                        xgrid=thetagrid, bwscale=bwscale, smooth=smooth, score=score)
+        m12 <- icc_items[, ccov.table[ff,1] ]*icc_items[, ccov.table[ff,2] ]
+        ccov.matrix[,ff] <- prod.matrix[,ff] - m12
+        # print progress
+        ii <- ccov_np_print_progress(progress=progress, i=ii, ii=ff, display=display)
     }
     # remove NAs from ccov.matrix
-    ccov.matrix[ is.na( ccov.matrix) ] <- 0
+    ccov.matrix[ is.na(ccov.matrix) ] <- 0
     sirt_progress_cat(progress=progress)
     # calculate (weighted) conditional covariance
     ccov.table$ccov <- apply( ccov.matrix, 2, FUN=function(sp){
-                        stats::weighted.mean( sp, wgt.thetagrid ) } )
+                        stats::weighted.mean( x=sp, w=wgt_thetagrid ) } )
     #--- output
     res <- list( ccov.table=ccov.table, ccov.matrix=ccov.matrix,
-                    data=data, score=score, icc.items=icc.items )
-    return( res )
-    }
+                    data=data, score=score, icc.items=icc_items,
+                    wgt.thetagrid=wgt_thetagrid)
+    return(res)
+}
 
